@@ -11,9 +11,10 @@ import logging
 
 def onexit(func: Callable):
     def wrapped_func(*args, **kwargs):
+        print("Exiting...")
         logging.debug(f"Exiting calling {func}")
         func(*args, **kwargs)
-        time.sleep(0.1)
+        time.sleep(1)
         print("Exited Bye")
         os._exit(0)
     return wrapped_func
